# time-dist-of-dets.R

library(jit)
NREPEATS <- 100

dd.for.c <- function()
{
  val <- NULL
  for (a in 0:9) for (b in 0:9) for (d in 0:9) for (e in 0:9)
     val <- c(val, a*b - d*e)
  table(val)
}
dd.for.c2 <- function()
{
  jit(1)
  val <- NULL
  nojit(val) # inhibit compilation of val
  for (a in 0:9) for (b in 0:9) for (d in 0:9) for (e in 0:9)
      val <- c(val, a*b - d*e)
  table(val)
}
dd.for.prealloc <- function()
{
  jit(1)
  val <- double(10000)    # preallocate val
  nval <- 0
  for (a in 0:9) for (b in 0:9) for (d in 0:9) for (e in 0:9)
    val[nval <- nval + 1] <- a*b - d*e
  table(val)
}
dd.for.tabulate <- function()
{
  jit(1)
  val <- double(10000)
  nval <- 0
  for (a in 0:9) for (b in 0:9) for (d in 0:9) for (e in 0:9)
    val[nval <- nval + 1] <- a*b - d*e
  tabulate(val)   # was table()
}
dd.fast.tabulate <- function()
{
    val <- outer(0:9, 0:9, "*")
    val <- outer(val, val, "-")
    tabulate(val)
}
do.time <- function(func)
{
    time <- system.time(for(i in 1:NREPEATS) func())[3]
    func.name <- deparse(substitute(func))
    if(func.name == "dd.for.c")
        reference.time <<- time # NOTE: <<- not <-
    stopifnot(!is.na(reference.time))
    cat(sprintf("%-16.16s %7.3f   %8.2f     %8.2f\n",
        func.name,
        time,
        time / reference.time,
        reference.time / time))
    time
}
cat(version$version.string, "\n\n")
cat("NREPEATS=", NREPEATS, "\n\n", sep="")
cat("Big \"relative\" means the given function is slow relative to dd.for.c\n\n")
cat("function            time   relative   1/relative\n")
reference.time <- NA
do.time(dd.for.c)
do.time(dd.for.c2)
do.time(dd.for.prealloc)
do.time(dd.for.tabulate)
do.time(dd.fast.tabulate)
